# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.automl_v1beta1.types import annotation_payload, data_items, io

__protobuf__ = proto.module(
    package="google.cloud.automl.v1beta1",
    manifest={
        "PredictRequest",
        "PredictResponse",
        "BatchPredictRequest",
        "BatchPredictResult",
    },
)


class PredictRequest(proto.Message):
    r"""Request message for
    [PredictionService.Predict][google.cloud.automl.v1beta1.PredictionService.Predict].

    Attributes:
        name (str):
            Required. Name of the model requested to
            serve the prediction.
        payload (google.cloud.automl_v1beta1.types.ExamplePayload):
            Required. Payload to perform a prediction on.
            The payload must match the problem type that the
            model was trained to solve.
        params (MutableMapping[str, str]):
            Additional domain-specific parameters, any string must be up
            to 25000 characters long.

            -  For Image Classification:

               ``score_threshold`` - (float) A value from 0.0 to 1.0.
               When the model makes predictions for an image, it will
               only produce results that have at least this confidence
               score. The default is 0.5.

            -  For Image Object Detection: ``score_threshold`` - (float)
               When Model detects objects on the image, it will only
               produce bounding boxes which have at least this
               confidence score. Value in 0 to 1 range, default is 0.5.
               ``max_bounding_box_count`` - (int64) No more than this
               number of bounding boxes will be returned in the
               response. Default is 100, the requested value may be
               limited by server.

            -  For Tables: feature_importance - (boolean) Whether
               feature importance should be populated in the returned
               TablesAnnotation. The default is false.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    payload: data_items.ExamplePayload = proto.Field(
        proto.MESSAGE,
        number=2,
        message=data_items.ExamplePayload,
    )
    params: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=3,
    )


class PredictResponse(proto.Message):
    r"""Response message for
    [PredictionService.Predict][google.cloud.automl.v1beta1.PredictionService.Predict].

    Attributes:
        payload (MutableSequence[google.cloud.automl_v1beta1.types.AnnotationPayload]):
            Prediction result.
            Translation and Text Sentiment will return
            precisely one payload.
        preprocessed_input (google.cloud.automl_v1beta1.types.ExamplePayload):
            The preprocessed example that AutoML actually makes
            prediction on. Empty if AutoML does not preprocess the input
            example.

            -  For Text Extraction: If the input is a .pdf file, the
               OCR'ed text will be provided in
               [document_text][google.cloud.automl.v1beta1.Document.document_text].
        metadata (MutableMapping[str, str]):
            Additional domain-specific prediction response metadata.

            -  For Image Object Detection: ``max_bounding_box_count`` -
               (int64) At most that many bounding boxes per image could
               have been returned.

            -  For Text Sentiment: ``sentiment_score`` - (float,
               deprecated) A value between -1 and 1, -1 maps to least
               positive sentiment, while 1 maps to the most positive one
               and the higher the score, the more positive the sentiment
               in the document is. Yet these values are relative to the
               training data, so e.g. if all data was positive then -1
               will be also positive (though the least). The
               sentiment_score shouldn't be confused with "score" or
               "magnitude" from the previous Natural Language Sentiment
               Analysis API.
    """

    payload: MutableSequence[
        annotation_payload.AnnotationPayload
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=annotation_payload.AnnotationPayload,
    )
    preprocessed_input: data_items.ExamplePayload = proto.Field(
        proto.MESSAGE,
        number=3,
        message=data_items.ExamplePayload,
    )
    metadata: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=2,
    )


class BatchPredictRequest(proto.Message):
    r"""Request message for
    [PredictionService.BatchPredict][google.cloud.automl.v1beta1.PredictionService.BatchPredict].

    Attributes:
        name (str):
            Required. Name of the model requested to
            serve the batch prediction.
        input_config (google.cloud.automl_v1beta1.types.BatchPredictInputConfig):
            Required. The input configuration for batch
            prediction.
        output_config (google.cloud.automl_v1beta1.types.BatchPredictOutputConfig):
            Required. The Configuration specifying where
            output predictions should be written.
        params (MutableMapping[str, str]):
            Required. Additional domain-specific parameters for the
            predictions, any string must be up to 25000 characters long.

            -  For Text Classification:

               ``score_threshold`` - (float) A value from 0.0 to 1.0.
               When the model makes predictions for a text snippet, it
               will only produce results that have at least this
               confidence score. The default is 0.5.

            -  For Image Classification:

               ``score_threshold`` - (float) A value from 0.0 to 1.0.
               When the model makes predictions for an image, it will
               only produce results that have at least this confidence
               score. The default is 0.5.

            -  For Image Object Detection:

               ``score_threshold`` - (float) When Model detects objects
               on the image, it will only produce bounding boxes which
               have at least this confidence score. Value in 0 to 1
               range, default is 0.5. ``max_bounding_box_count`` -
               (int64) No more than this number of bounding boxes will
               be produced per image. Default is 100, the requested
               value may be limited by server.

            -  For Video Classification :

               ``score_threshold`` - (float) A value from 0.0 to 1.0.
               When the model makes predictions for a video, it will
               only produce results that have at least this confidence
               score. The default is 0.5. ``segment_classification`` -
               (boolean) Set to true to request segment-level
               classification. AutoML Video Intelligence returns labels
               and their confidence scores for the entire segment of the
               video that user specified in the request configuration.
               The default is "true". ``shot_classification`` -
               (boolean) Set to true to request shot-level
               classification. AutoML Video Intelligence determines the
               boundaries for each camera shot in the entire segment of
               the video that user specified in the request
               configuration. AutoML Video Intelligence then returns
               labels and their confidence scores for each detected
               shot, along with the start and end time of the shot.
               WARNING: Model evaluation is not done for this
               classification type, the quality of it depends on
               training data, but there are no metrics provided to
               describe that quality. The default is "false".
               ``1s_interval_classification`` - (boolean) Set to true to
               request classification for a video at one-second
               intervals. AutoML Video Intelligence returns labels and
               their confidence scores for each second of the entire
               segment of the video that user specified in the request
               configuration. WARNING: Model evaluation is not done for
               this classification type, the quality of it depends on
               training data, but there are no metrics provided to
               describe that quality. The default is "false".

            -  For Tables:

               feature_importance - (boolean) Whether feature importance
               should be populated in the returned TablesAnnotations.
               The default is false.

            -  For Video Object Tracking:

               ``score_threshold`` - (float) When Model detects objects
               on video frames, it will only produce bounding boxes
               which have at least this confidence score. Value in 0 to
               1 range, default is 0.5. ``max_bounding_box_count`` -
               (int64) No more than this number of bounding boxes will
               be returned per frame. Default is 100, the requested
               value may be limited by server. ``min_bounding_box_size``
               - (float) Only bounding boxes with shortest edge at least
               that long as a relative value of video frame size will be
               returned. Value in 0 to 1 range. Default is 0.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    input_config: io.BatchPredictInputConfig = proto.Field(
        proto.MESSAGE,
        number=3,
        message=io.BatchPredictInputConfig,
    )
    output_config: io.BatchPredictOutputConfig = proto.Field(
        proto.MESSAGE,
        number=4,
        message=io.BatchPredictOutputConfig,
    )
    params: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=5,
    )


class BatchPredictResult(proto.Message):
    r"""Result of the Batch Predict. This message is returned in
    [response][google.longrunning.Operation.response] of the operation
    returned by the
    [PredictionService.BatchPredict][google.cloud.automl.v1beta1.PredictionService.BatchPredict].

    Attributes:
        metadata (MutableMapping[str, str]):
            Additional domain-specific prediction response metadata.

            -  For Image Object Detection: ``max_bounding_box_count`` -
               (int64) At most that many bounding boxes per image could
               have been returned.

            -  For Video Object Tracking: ``max_bounding_box_count`` -
               (int64) At most that many bounding boxes per frame could
               have been returned.
    """

    metadata: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.automl_v1beta1.types import classification

__protobuf__ = proto.module(
    package="google.cloud.automl.v1beta1",
    manifest={
        "TextClassificationDatasetMetadata",
        "TextClassificationModelMetadata",
        "TextExtractionDatasetMetadata",
        "TextExtractionModelMetadata",
        "TextSentimentDatasetMetadata",
        "TextSentimentModelMetadata",
    },
)


class TextClassificationDatasetMetadata(proto.Message):
    r"""Dataset metadata for classification.

    Attributes:
        classification_type (google.cloud.automl_v1beta1.types.ClassificationType):
            Required. Type of the classification problem.
    """

    classification_type: classification.ClassificationType = proto.Field(
        proto.ENUM,
        number=1,
        enum=classification.ClassificationType,
    )


class TextClassificationModelMetadata(proto.Message):
    r"""Model metadata that is specific to text classification.

    Attributes:
        classification_type (google.cloud.automl_v1beta1.types.ClassificationType):
            Output only. Classification type of the
            dataset used to train this model.
    """

    classification_type: classification.ClassificationType = proto.Field(
        proto.ENUM,
        number=3,
        enum=classification.ClassificationType,
    )


class TextExtractionDatasetMetadata(proto.Message):
    r"""Dataset metadata that is specific to text extraction"""


class TextExtractionModelMetadata(proto.Message):
    r"""Model metadata that is specific to text extraction.

    Attributes:
        model_hint (str):
            Indicates the scope of model use case.

            -  ``default``: Use to train a general text extraction
               model. Default value.

            -  ``health_care``: Use to train a text extraction model
               that is tuned for healthcare applications.
    """

    model_hint: str = proto.Field(
        proto.STRING,
        number=3,
    )


class TextSentimentDatasetMetadata(proto.Message):
    r"""Dataset metadata for text sentiment.

    Attributes:
        sentiment_max (int):
            Required. A sentiment is expressed as an integer ordinal,
            where higher value means a more positive sentiment. The
            range of sentiments that will be used is between 0 and
            sentiment_max (inclusive on both ends), and all the values
            in the range must be represented in the dataset before a
            model can be created. sentiment_max value must be between 1
            and 10 (inclusive).
    """

    sentiment_max: int = proto.Field(
        proto.INT32,
        number=1,
    )


class TextSentimentModelMetadata(proto.Message):
    r"""Model metadata that is specific to text sentiment."""


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.automl_v1.types import classification

__protobuf__ = proto.module(
    package="google.cloud.automl.v1",
    manifest={
        "ImageClassificationDatasetMetadata",
        "ImageObjectDetectionDatasetMetadata",
        "ImageClassificationModelMetadata",
        "ImageObjectDetectionModelMetadata",
        "ImageClassificationModelDeploymentMetadata",
        "ImageObjectDetectionModelDeploymentMetadata",
    },
)


class ImageClassificationDatasetMetadata(proto.Message):
    r"""Dataset metadata that is specific to image classification.

    Attributes:
        classification_type (google.cloud.automl_v1.types.ClassificationType):
            Required. Type of the classification problem.
    """

    classification_type: classification.ClassificationType = proto.Field(
        proto.ENUM,
        number=1,
        enum=classification.ClassificationType,
    )


class ImageObjectDetectionDatasetMetadata(proto.Message):
    r"""Dataset metadata specific to image object detection."""


class ImageClassificationModelMetadata(proto.Message):
    r"""Model metadata for image classification.

    Attributes:
        base_model_id (str):
            Optional. The ID of the ``base`` model. If it is specified,
            the new model will be created based on the ``base`` model.
            Otherwise, the new model will be created from scratch. The
            ``base`` model must be in the same ``project`` and
            ``location`` as the new model to create, and have the same
            ``model_type``.
        train_budget_milli_node_hours (int):
            Optional. The train budget of creating this model, expressed
            in milli node hours i.e. 1,000 value in this field means 1
            node hour. The actual ``train_cost`` will be equal or less
            than this value. If further model training ceases to provide
            any improvements, it will stop without using full budget and
            the stop_reason will be ``MODEL_CONVERGED``. Note, node_hour
            = actual_hour \* number_of_nodes_invovled. For model type
            ``cloud``\ (default), the train budget must be between 8,000
            and 800,000 milli node hours, inclusive. The default value
            is 192, 000 which represents one day in wall time. For model
            type ``mobile-low-latency-1``, ``mobile-versatile-1``,
            ``mobile-high-accuracy-1``,
            ``mobile-core-ml-low-latency-1``,
            ``mobile-core-ml-versatile-1``,
            ``mobile-core-ml-high-accuracy-1``, the train budget must be
            between 1,000 and 100,000 milli node hours, inclusive. The
            default value is 24, 000 which represents one day in wall
            time.
        train_cost_milli_node_hours (int):
            Output only. The actual train cost of
            creating this model, expressed in milli node
            hours, i.e. 1,000 value in this field means 1
            node hour. Guaranteed to not exceed the train
            budget.
        stop_reason (str):
            Output only. The reason that this create model operation
            stopped, e.g. ``BUDGET_REACHED``, ``MODEL_CONVERGED``.
        model_type (str):
            Optional. Type of the model. The available values are:

            -  ``cloud`` - Model to be used via prediction calls to
               AutoML API. This is the default value.
            -  ``mobile-low-latency-1`` - A model that, in addition to
               providing prediction via AutoML API, can also be exported
               (see
               [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel])
               and used on a mobile or edge device with TensorFlow
               afterwards. Expected to have low latency, but may have
               lower prediction quality than other models.
            -  ``mobile-versatile-1`` - A model that, in addition to
               providing prediction via AutoML API, can also be exported
               (see
               [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel])
               and used on a mobile or edge device with TensorFlow
               afterwards.
            -  ``mobile-high-accuracy-1`` - A model that, in addition to
               providing prediction via AutoML API, can also be exported
               (see
               [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel])
               and used on a mobile or edge device with TensorFlow
               afterwards. Expected to have a higher latency, but should
               also have a higher prediction quality than other models.
            -  ``mobile-core-ml-low-latency-1`` - A model that, in
               addition to providing prediction via AutoML API, can also
               be exported (see
               [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel])
               and used on a mobile device with Core ML afterwards.
               Expected to have low latency, but may have lower
               prediction quality than other models.
            -  ``mobile-core-ml-versatile-1`` - A model that, in
               addition to providing prediction via AutoML API, can also
               be exported (see
               [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel])
               and used on a mobile device with Core ML afterwards.
            -  ``mobile-core-ml-high-accuracy-1`` - A model that, in
               addition to providing prediction via AutoML API, can also
               be exported (see
               [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel])
               and used on a mobile device with Core ML afterwards.
               Expected to have a higher latency, but should also have a
               higher prediction quality than other models.
        node_qps (float):
            Output only. An approximate number of online
            prediction QPS that can be supported by this
            model per each node on which it is deployed.
        node_count (int):
            Output only. The number of nodes this model is deployed on.
            A node is an abstraction of a machine resource, which can
            handle online prediction QPS as given in the node_qps field.
    """

    base_model_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    train_budget_milli_node_hours: int = proto.Field(
        proto.INT64,
        number=16,
    )
    train_cost_milli_node_hours: int = proto.Field(
        proto.INT64,
        number=17,
    )
    stop_reason: str = proto.Field(
        proto.STRING,
        number=5,
    )
    model_type: str = proto.Field(
        proto.STRING,
        number=7,
    )
    node_qps: float = proto.Field(
        proto.DOUBLE,
        number=13,
    )
    node_count: int = proto.Field(
        proto.INT64,
        number=14,
    )


class ImageObjectDetectionModelMetadata(proto.Message):
    r"""Model metadata specific to image object detection.

    Attributes:
        model_type (str):
            Optional. Type of the model. The available values are:

            -  ``cloud-high-accuracy-1`` - (default) A model to be used
               via prediction calls to AutoML API. Expected to have a
               higher latency, but should also have a higher prediction
               quality than other models.
            -  ``cloud-low-latency-1`` - A model to be used via
               prediction calls to AutoML API. Expected to have low
               latency, but may have lower prediction quality than other
               models.
            -  ``mobile-low-latency-1`` - A model that, in addition to
               providing prediction via AutoML API, can also be exported
               (see
               [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel])
               and used on a mobile or edge device with TensorFlow
               afterwards. Expected to have low latency, but may have
               lower prediction quality than other models.
            -  ``mobile-versatile-1`` - A model that, in addition to
               providing prediction via AutoML API, can also be exported
               (see
               [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel])
               and used on a mobile or edge device with TensorFlow
               afterwards.
            -  ``mobile-high-accuracy-1`` - A model that, in addition to
               providing prediction via AutoML API, can also be exported
               (see
               [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel])
               and used on a mobile or edge device with TensorFlow
               afterwards. Expected to have a higher latency, but should
               also have a higher prediction quality than other models.
        node_count (int):
            Output only. The number of nodes this model is deployed on.
            A node is an abstraction of a machine resource, which can
            handle online prediction QPS as given in the qps_per_node
            field.
        node_qps (float):
            Output only. An approximate number of online
            prediction QPS that can be supported by this
            model per each node on which it is deployed.
        stop_reason (str):
            Output only. The reason that this create model operation
            stopped, e.g. ``BUDGET_REACHED``, ``MODEL_CONVERGED``.
        train_budget_milli_node_hours (int):
            Optional. The train budget of creating this model, expressed
            in milli node hours i.e. 1,000 value in this field means 1
            node hour. The actual ``train_cost`` will be equal or less
            than this value. If further model training ceases to provide
            any improvements, it will stop without using full budget and
            the stop_reason will be ``MODEL_CONVERGED``. Note, node_hour
            = actual_hour \* number_of_nodes_invovled. For model type
            ``cloud-high-accuracy-1``\ (default) and
            ``cloud-low-latency-1``, the train budget must be between
            20,000 and 900,000 milli node hours, inclusive. The default
            value is 216, 000 which represents one day in wall time. For
            model type ``mobile-low-latency-1``, ``mobile-versatile-1``,
            ``mobile-high-accuracy-1``,
            ``mobile-core-ml-low-latency-1``,
            ``mobile-core-ml-versatile-1``,
            ``mobile-core-ml-high-accuracy-1``, the train budget must be
            between 1,000 and 100,000 milli node hours, inclusive. The
            default value is 24, 000 which represents one day in wall
            time.
        train_cost_milli_node_hours (int):
            Output only. The actual train cost of
            creating this model, expressed in milli node
            hours, i.e. 1,000 value in this field means 1
            node hour. Guaranteed to not exceed the train
            budget.
    """

    model_type: str = proto.Field(
        proto.STRING,
        number=1,
    )
    node_count: int = proto.Field(
        proto.INT64,
        number=3,
    )
    node_qps: float = proto.Field(
        proto.DOUBLE,
        number=4,
    )
    stop_reason: str = proto.Field(
        proto.STRING,
        number=5,
    )
    train_budget_milli_node_hours: int = proto.Field(
        proto.INT64,
        number=6,
    )
    train_cost_milli_node_hours: int = proto.Field(
        proto.INT64,
        number=7,
    )


class ImageClassificationModelDeploymentMetadata(proto.Message):
    r"""Model deployment metadata specific to Image Classification.

    Attributes:
        node_count (int):
            Input only. The number of nodes to deploy the model on. A
            node is an abstraction of a machine resource, which can
            handle online prediction QPS as given in the model's
            [node_qps][google.cloud.automl.v1.ImageClassificationModelMetadata.node_qps].
            Must be between 1 and 100, inclusive on both ends.
    """

    node_count: int = proto.Field(
        proto.INT64,
        number=1,
    )


class ImageObjectDetectionModelDeploymentMetadata(proto.Message):
    r"""Model deployment metadata specific to Image Object Detection.

    Attributes:
        node_count (int):
            Input only. The number of nodes to deploy the model on. A
            node is an abstraction of a machine resource, which can
            handle online prediction QPS as given in the model's
            [qps_per_node][google.cloud.automl.v1.ImageObjectDetectionModelMetadata.qps_per_node].
            Must be between 1 and 100, inclusive on both ends.
    """

    node_count: int = proto.Field(
        proto.INT64,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.automl.v1",
    manifest={
        "ClassificationType",
        "ClassificationAnnotation",
        "ClassificationEvaluationMetrics",
    },
)


class ClassificationType(proto.Enum):
    r"""Type of the classification problem.

    Values:
        CLASSIFICATION_TYPE_UNSPECIFIED (0):
            An un-set value of this enum.
        MULTICLASS (1):
            At most one label is allowed per example.
        MULTILABEL (2):
            Multiple labels are allowed for one example.
    """
    CLASSIFICATION_TYPE_UNSPECIFIED = 0
    MULTICLASS = 1
    MULTILABEL = 2


class ClassificationAnnotation(proto.Message):
    r"""Contains annotation details specific to classification.

    Attributes:
        score (float):
            Output only. A confidence estimate between
            0.0 and 1.0. A higher value means greater
            confidence that the annotation is positive. If a
            user approves an annotation as negative or
            positive, the score value remains unchanged. If
            a user creates an annotation, the score is 0 for
            negative or 1 for positive.
    """

    score: float = proto.Field(
        proto.FLOAT,
        number=1,
    )


class ClassificationEvaluationMetrics(proto.Message):
    r"""Model evaluation metrics for classification problems. Note: For
    Video Classification this metrics only describe quality of the Video
    Classification predictions of "segment_classification" type.

    Attributes:
        au_prc (float):
            Output only. The Area Under Precision-Recall
            Curve metric. Micro-averaged for the overall
            evaluation.
        au_roc (float):
            Output only. The Area Under Receiver
            Operating Characteristic curve metric.
            Micro-averaged for the overall evaluation.
        log_loss (float):
            Output only. The Log Loss metric.
        confidence_metrics_entry (MutableSequence[google.cloud.automl_v1.types.ClassificationEvaluationMetrics.ConfidenceMetricsEntry]):
            Output only. Metrics for each confidence_threshold in
            0.00,0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and
            position_threshold = INT32_MAX_VALUE. ROC and
            precision-recall curves, and other aggregated metrics are
            derived from them. The confidence metrics entries may also
            be supplied for additional values of position_threshold, but
            from these no aggregated metrics are computed.
        confusion_matrix (google.cloud.automl_v1.types.ClassificationEvaluationMetrics.ConfusionMatrix):
            Output only. Confusion matrix of the
            evaluation. Only set for MULTICLASS
            classification problems where number of labels
            is no more than 10.
            Only set for model level evaluation, not for
            evaluation per label.
        annotation_spec_id (MutableSequence[str]):
            Output only. The annotation spec ids used for
            this evaluation.
    """

    class ConfidenceMetricsEntry(proto.Message):
        r"""Metrics for a single confidence threshold.

        Attributes:
            confidence_threshold (float):
                Output only. Metrics are computed with an
                assumption that the model never returns
                predictions with score lower than this value.
            position_threshold (int):
                Output only. Metrics are computed with an assumption that
                the model always returns at most this many predictions
                (ordered by their score, descendingly), but they all still
                need to meet the confidence_threshold.
            recall (float):
                Output only. Recall (True Positive Rate) for
                the given confidence threshold.
            precision (float):
                Output only. Precision for the given
                confidence threshold.
            false_positive_rate (float):
                Output only. False Positive Rate for the
                given confidence threshold.
            f1_score (float):
                Output only. The harmonic mean of recall and
                precision.
            recall_at1 (float):
                Output only. The Recall (True Positive Rate)
                when only considering the label that has the
                highest prediction score and not below the
                confidence threshold for each example.
            precision_at1 (float):
                Output only. The precision when only
                considering the label that has the highest
                prediction score and not below the confidence
                threshold for each example.
            false_positive_rate_at1 (float):
                Output only. The False Positive Rate when
                only considering the label that has the highest
                prediction score and not below the confidence
                threshold for each example.
            f1_score_at1 (float):
                Output only. The harmonic mean of
                [recall_at1][google.cloud.automl.v1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.recall_at1]
                and
                [precision_at1][google.cloud.automl.v1.ClassificationEvaluationMetrics.ConfidenceMetricsEntry.precision_at1].
            true_positive_count (int):
                Output only. The number of model created
                labels that match a ground truth label.
            false_positive_count (int):
                Output only. The number of model created
                labels that do not match a ground truth label.
            false_negative_count (int):
                Output only. The number of ground truth
                labels that are not matched by a model created
                label.
            true_negative_count (int):
                Output only. The number of labels that were
                not created by the model, but if they would,
                they would not match a ground truth label.
        """

        confidence_threshold: float = proto.Field(
            proto.FLOAT,
            number=1,
        )
        position_threshold: int = proto.Field(
            proto.INT32,
            number=14,
        )
        recall: float = proto.Field(
            proto.FLOAT,
            number=2,
        )
        precision: float = proto.Field(
            proto.FLOAT,
            number=3,
        )
        false_positive_rate: float = proto.Field(
            proto.FLOAT,
            number=8,
        )
        f1_score: float = proto.Field(
            proto.FLOAT,
            number=4,
        )
        recall_at1: float = proto.Field(
            proto.FLOAT,
            number=5,
        )
        precision_at1: float = proto.Field(
            proto.FLOAT,
            number=6,
        )
        false_positive_rate_at1: float = proto.Field(
            proto.FLOAT,
            number=9,
        )
        f1_score_at1: float = proto.Field(
            proto.FLOAT,
            number=7,
        )
        true_positive_count: int = proto.Field(
            proto.INT64,
            number=10,
        )
        false_positive_count: int = proto.Field(
            proto.INT64,
            number=11,
        )
        false_negative_count: int = proto.Field(
            proto.INT64,
            number=12,
        )
        true_negative_count: int = proto.Field(
            proto.INT64,
            number=13,
        )

    class ConfusionMatrix(proto.Message):
        r"""Confusion matrix of the model running the classification.

        Attributes:
            annotation_spec_id (MutableSequence[str]):
                Output only. IDs of the annotation specs used in the
                confusion matrix. For Tables CLASSIFICATION
                [prediction_type][google.cloud.automl.v1p1beta.TablesModelMetadata.prediction_type]
                only list of [annotation_spec_display_name-s][] is
                populated.
            display_name (MutableSequence[str]):
                Output only. Display name of the annotation specs used in
                the confusion matrix, as they were at the moment of the
                evaluation. For Tables CLASSIFICATION
                [prediction_type-s][google.cloud.automl.v1p1beta.TablesModelMetadata.prediction_type],
                distinct values of the target column at the moment of the
                model evaluation are populated here.
            row (MutableSequence[google.cloud.automl_v1.types.ClassificationEvaluationMetrics.ConfusionMatrix.Row]):
                Output only. Rows in the confusion matrix. The number of
                rows is equal to the size of ``annotation_spec_id``.
                ``row[i].example_count[j]`` is the number of examples that
                have ground truth of the ``annotation_spec_id[i]`` and are
                predicted as ``annotation_spec_id[j]`` by the model being
                evaluated.
        """

        class Row(proto.Message):
            r"""Output only. A row in the confusion matrix.

            Attributes:
                example_count (MutableSequence[int]):
                    Output only. Value of the specific cell in the confusion
                    matrix. The number of values each row has (i.e. the length
                    of the row) is equal to the length of the
                    ``annotation_spec_id`` field or, if that one is not
                    populated, length of the
                    [display_name][google.cloud.automl.v1.ClassificationEvaluationMetrics.ConfusionMatrix.display_name]
                    field.
            """

            example_count: MutableSequence[int] = proto.RepeatedField(
                proto.INT32,
                number=1,
            )

        annotation_spec_id: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=1,
        )
        display_name: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=3,
        )
        row: MutableSequence[
            "ClassificationEvaluationMetrics.ConfusionMatrix.Row"
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="ClassificationEvaluationMetrics.ConfusionMatrix.Row",
        )

    au_prc: float = proto.Field(
        proto.FLOAT,
        number=1,
    )
    au_roc: float = proto.Field(
        proto.FLOAT,
        number=6,
    )
    log_loss: float = proto.Field(
        proto.FLOAT,
        number=7,
    )
    confidence_metrics_entry: MutableSequence[
        ConfidenceMetricsEntry
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=ConfidenceMetricsEntry,
    )
    confusion_matrix: ConfusionMatrix = proto.Field(
        proto.MESSAGE,
        number=4,
        message=ConfusionMatrix,
    )
    annotation_spec_id: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.automl_v1beta1.types import data_items

__protobuf__ = proto.module(
    package="google.cloud.automl.v1beta1",
    manifest={
        "TranslationDatasetMetadata",
        "TranslationEvaluationMetrics",
        "TranslationModelMetadata",
        "TranslationAnnotation",
    },
)


class TranslationDatasetMetadata(proto.Message):
    r"""Dataset metadata that is specific to translation.

    Attributes:
        source_language_code (str):
            Required. The BCP-47 language code of the
            source language.
        target_language_code (str):
            Required. The BCP-47 language code of the
            target language.
    """

    source_language_code: str = proto.Field(
        proto.STRING,
        number=1,
    )
    target_language_code: str = proto.Field(
        proto.STRING,
        number=2,
    )


class TranslationEvaluationMetrics(proto.Message):
    r"""Evaluation metrics for the dataset.

    Attributes:
        bleu_score (float):
            Output only. BLEU score.
        base_bleu_score (float):
            Output only. BLEU score for base model.
    """

    bleu_score: float = proto.Field(
        proto.DOUBLE,
        number=1,
    )
    base_bleu_score: float = proto.Field(
        proto.DOUBLE,
        number=2,
    )


class TranslationModelMetadata(proto.Message):
    r"""Model metadata that is specific to translation.

    Attributes:
        base_model (str):
            The resource name of the model to use as a baseline to train
            the custom model. If unset, we use the default base model
            provided by Google Translate. Format:
            ``projects/{project_id}/locations/{location_id}/models/{model_id}``
        source_language_code (str):
            Output only. Inferred from the dataset.
            The source languge (The BCP-47 language code)
            that is used for training.
        target_language_code (str):
            Output only. The target languge (The BCP-47
            language code) that is used for training.
    """

    base_model: str = proto.Field(
        proto.STRING,
        number=1,
    )
    source_language_code: str = proto.Field(
        proto.STRING,
        number=2,
    )
    target_language_code: str = proto.Field(
        proto.STRING,
        number=3,
    )


class TranslationAnnotation(proto.Message):
    r"""Annotation details specific to translation.

    Attributes:
        translated_content (google.cloud.automl_v1beta1.types.TextSnippet):
            Output only . The translated content.
    """

    translated_content: data_items.TextSnippet = proto.Field(
        proto.MESSAGE,
        number=1,
        message=data_items.TextSnippet,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.automl_v1beta1.types import image, tables, text, translation, video

__protobuf__ = proto.module(
    package="google.cloud.automl.v1beta1",
    manifest={
        "Dataset",
    },
)


class Dataset(proto.Message):
    r"""A workspace for solving a single, particular machine learning
    (ML) problem. A workspace contains examples that may be
    annotated.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        translation_dataset_metadata (google.cloud.automl_v1beta1.types.TranslationDatasetMetadata):
            Metadata for a dataset used for translation.

            This field is a member of `oneof`_ ``dataset_metadata``.
        image_classification_dataset_metadata (google.cloud.automl_v1beta1.types.ImageClassificationDatasetMetadata):
            Metadata for a dataset used for image
            classification.

            This field is a member of `oneof`_ ``dataset_metadata``.
        text_classification_dataset_metadata (google.cloud.automl_v1beta1.types.TextClassificationDatasetMetadata):
            Metadata for a dataset used for text
            classification.

            This field is a member of `oneof`_ ``dataset_metadata``.
        image_object_detection_dataset_metadata (google.cloud.automl_v1beta1.types.ImageObjectDetectionDatasetMetadata):
            Metadata for a dataset used for image object
            detection.

            This field is a member of `oneof`_ ``dataset_metadata``.
        video_classification_dataset_metadata (google.cloud.automl_v1beta1.types.VideoClassificationDatasetMetadata):
            Metadata for a dataset used for video
            classification.

            This field is a member of `oneof`_ ``dataset_metadata``.
        video_object_tracking_dataset_metadata (google.cloud.automl_v1beta1.types.VideoObjectTrackingDatasetMetadata):
            Metadata for a dataset used for video object
            tracking.

            This field is a member of `oneof`_ ``dataset_metadata``.
        text_extraction_dataset_metadata (google.cloud.automl_v1beta1.types.TextExtractionDatasetMetadata):
            Metadata for a dataset used for text
            extraction.

            This field is a member of `oneof`_ ``dataset_metadata``.
        text_sentiment_dataset_metadata (google.cloud.automl_v1beta1.types.TextSentimentDatasetMetadata):
            Metadata for a dataset used for text
            sentiment.

            This field is a member of `oneof`_ ``dataset_metadata``.
        tables_dataset_metadata (google.cloud.automl_v1beta1.types.TablesDatasetMetadata):
            Metadata for a dataset used for Tables.

            This field is a member of `oneof`_ ``dataset_metadata``.
        name (str):
            Output only. The resource name of the dataset. Form:
            ``projects/{project_id}/locations/{location_id}/datasets/{dataset_id}``
        display_name (str):
            Required. The name of the dataset to show in the interface.
            The name can be up to 32 characters long and can consist
            only of ASCII Latin letters A-Z and a-z, underscores (_),
            and ASCII digits 0-9.
        description (str):
            User-provided description of the dataset. The
            description can be up to 25000 characters long.
        example_count (int):
            Output only. The number of examples in the
            dataset.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when this dataset was
            created.
        etag (str):
            Used to perform consistent read-modify-write
            updates. If not set, a blind "overwrite" update
            happens.
    """

    translation_dataset_metadata: translation.TranslationDatasetMetadata = proto.Field(
        proto.MESSAGE,
        number=23,
        oneof="dataset_metadata",
        message=translation.TranslationDatasetMetadata,
    )
    image_classification_dataset_metadata: image.ImageClassificationDatasetMetadata = (
        proto.Field(
            proto.MESSAGE,
            number=24,
            oneof="dataset_metadata",
            message=image.ImageClassificationDatasetMetadata,
        )
    )
    text_classification_dataset_metadata: text.TextClassificationDatasetMetadata = (
        proto.Field(
            proto.MESSAGE,
            number=25,
            oneof="dataset_metadata",
            message=text.TextClassificationDatasetMetadata,
        )
    )
    image_object_detection_dataset_metadata: image.ImageObjectDetectionDatasetMetadata = proto.Field(
        proto.MESSAGE,
        number=26,
        oneof="dataset_metadata",
        message=image.ImageObjectDetectionDatasetMetadata,
    )
    video_classification_dataset_metadata: video.VideoClassificationDatasetMetadata = (
        proto.Field(
            proto.MESSAGE,
            number=31,
            oneof="dataset_metadata",
            message=video.VideoClassificationDatasetMetadata,
        )
    )
    video_object_tracking_dataset_metadata: video.VideoObjectTrackingDatasetMetadata = (
        proto.Field(
            proto.MESSAGE,
            number=29,
            oneof="dataset_metadata",
            message=video.VideoObjectTrackingDatasetMetadata,
        )
    )
    text_extraction_dataset_metadata: text.TextExtractionDatasetMetadata = proto.Field(
        proto.MESSAGE,
        number=28,
        oneof="dataset_metadata",
        message=text.TextExtractionDatasetMetadata,
    )
    text_sentiment_dataset_metadata: text.TextSentimentDatasetMetadata = proto.Field(
        proto.MESSAGE,
        number=30,
        oneof="dataset_metadata",
        message=text.TextSentimentDatasetMetadata,
    )
    tables_dataset_metadata: tables.TablesDatasetMetadata = proto.Field(
        proto.MESSAGE,
        number=33,
        oneof="dataset_metadata",
        message=tables.TablesDatasetMetadata,
    )
    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    example_count: int = proto.Field(
        proto.INT32,
        number=21,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=14,
        message=timestamp_pb2.Timestamp,
    )
    etag: str = proto.Field(
        proto.STRING,
        number=17,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.automl.v1beta1",
    manifest={
        "RegressionEvaluationMetrics",
    },
)


class RegressionEvaluationMetrics(proto.Message):
    r"""Metrics for regression problems.

    Attributes:
        root_mean_squared_error (float):
            Output only. Root Mean Squared Error (RMSE).
        mean_absolute_error (float):
            Output only. Mean Absolute Error (MAE).
        mean_absolute_percentage_error (float):
            Output only. Mean absolute percentage error.
            Only set if all ground truth values are are
            positive.
        r_squared (float):
            Output only. R squared.
        root_mean_squared_log_error (float):
            Output only. Root mean squared log error.
    """

    root_mean_squared_error: float = proto.Field(
        proto.FLOAT,
        number=1,
    )
    mean_absolute_error: float = proto.Field(
        proto.FLOAT,
        number=2,
    )
    mean_absolute_percentage_error: float = proto.Field(
        proto.FLOAT,
        number=3,
    )
    r_squared: float = proto.Field(
        proto.FLOAT,
        number=4,
    )
    root_mean_squared_log_error: float = proto.Field(
        proto.FLOAT,
        number=5,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.automl_v1beta1.types import geometry

__protobuf__ = proto.module(
    package="google.cloud.automl.v1beta1",
    manifest={
        "ImageObjectDetectionAnnotation",
        "VideoObjectTrackingAnnotation",
        "BoundingBoxMetricsEntry",
        "ImageObjectDetectionEvaluationMetrics",
        "VideoObjectTrackingEvaluationMetrics",
    },
)


class ImageObjectDetectionAnnotation(proto.Message):
    r"""Annotation details for image object detection.

    Attributes:
        bounding_box (google.cloud.automl_v1beta1.types.BoundingPoly):
            Output only. The rectangle representing the
            object location.
        score (float):
            Output only. The confidence that this annotation is positive
            for the parent example, value in [0, 1], higher means higher
            positivity confidence.
    """

    bounding_box: geometry.BoundingPoly = proto.Field(
        proto.MESSAGE,
        number=1,
        message=geometry.BoundingPoly,
    )
    score: float = proto.Field(
        proto.FLOAT,
        number=2,
    )


class VideoObjectTrackingAnnotation(proto.Message):
    r"""Annotation details for video object tracking.

    Attributes:
        instance_id (str):
            Optional. The instance of the object,
            expressed as a positive integer. Used to tell
            apart objects of the same type (i.e.
            AnnotationSpec) when multiple are present on a
            single example.
            NOTE: Instance ID prediction quality is not a
            part of model evaluation and is done as best
            effort. Especially in cases when an entity goes
            off-screen for a longer time (minutes), when it
            comes back it may be given a new instance ID.
        time_offset (google.protobuf.duration_pb2.Duration):
            Required. A time (frame) of a video to which
            this annotation pertains. Represented as the
            duration since the video's start.
        bounding_box (google.cloud.automl_v1beta1.types.BoundingPoly):
            Required. The rectangle representing the object location on
            the frame (i.e. at the time_offset of the video).
        score (float):
            Output only. The confidence that this annotation is positive
            for the video at the time_offset, value in [0, 1], higher
            means higher positivity confidence. For annotations created
            by the user the score is 1. When user approves an
            annotation, the original float score is kept (and not
            changed to 1).
    """

    instance_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    time_offset: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=2,
        message=duration_pb2.Duration,
    )
    bounding_box: geometry.BoundingPoly = proto.Field(
        proto.MESSAGE,
        number=3,
        message=geometry.BoundingPoly,
    )
    score: float = proto.Field(
        proto.FLOAT,
        number=4,
    )


class BoundingBoxMetricsEntry(proto.Message):
    r"""Bounding box matching model metrics for a single
    intersection-over-union threshold and multiple label match
    confidence thresholds.

    Attributes:
        iou_threshold (float):
            Output only. The intersection-over-union
            threshold value used to compute this metrics
            entry.
        mean_average_precision (float):
            Output only. The mean average precision, most often close to
            au_prc.
        confidence_metrics_entries (MutableSequence[google.cloud.automl_v1beta1.types.BoundingBoxMetricsEntry.ConfidenceMetricsEntry]):
            Output only. Metrics for each label-match
            confidence_threshold from
            0.05,0.10,...,0.95,0.96,0.97,0.98,0.99. Precision-recall
            curve is derived from them.
    """

    class ConfidenceMetricsEntry(proto.Message):
        r"""Metrics for a single confidence threshold.

        Attributes:
            confidence_threshold (float):
                Output only. The confidence threshold value
                used to compute the metrics.
            recall (float):
                Output only. Recall under the given
                confidence threshold.
            precision (float):
                Output only. Precision under the given
                confidence threshold.
            f1_score (float):
                Output only. The harmonic mean of recall and
                precision.
        """

        confidence_threshold: float = proto.Field(
            proto.FLOAT,
            number=1,
        )
        recall: float = proto.Field(
            proto.FLOAT,
            number=2,
        )
        precision: float = proto.Field(
            proto.FLOAT,
            number=3,
        )
        f1_score: float = proto.Field(
            proto.FLOAT,
            number=4,
        )

    iou_threshold: float = proto.Field(
        proto.FLOAT,
        number=1,
    )
    mean_average_precision: float = proto.Field(
        proto.FLOAT,
        number=2,
    )
    confidence_metrics_entries: MutableSequence[
        ConfidenceMetricsEntry
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=ConfidenceMetricsEntry,
    )


class ImageObjectDetectionEvaluationMetrics(proto.Message):
    r"""Model evaluation metrics for image object detection problems.
    Evaluates prediction quality of labeled bounding boxes.

    Attributes:
        evaluated_bounding_box_count (int):
            Output only. The total number of bounding
            boxes (i.e. summed over all images) the ground
            truth used to create this evaluation had.
        bounding_box_metrics_entries (MutableSequence[google.cloud.automl_v1beta1.types.BoundingBoxMetricsEntry]):
            Output only. The bounding boxes match metrics
            for each Intersection-over-union threshold
            0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each
            label confidence threshold
            0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
        bounding_box_mean_average_precision (float):
            Output only. The single metric for bounding boxes
            evaluation: the mean_average_precision averaged over all
            bounding_box_metrics_entries.
    """

    evaluated_bounding_box_count: int = proto.Field(
        proto.INT32,
        number=1,
    )
    bounding_box_metrics_entries: MutableSequence[
        "BoundingBoxMetricsEntry"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="BoundingBoxMetricsEntry",
    )
    bounding_box_mean_average_precision: float = proto.Field(
        proto.FLOAT,
        number=3,
    )


class VideoObjectTrackingEvaluationMetrics(proto.Message):
    r"""Model evaluation metrics for video object tracking problems.
    Evaluates prediction quality of both labeled bounding boxes and
    labeled tracks (i.e. series of bounding boxes sharing same label
    and instance ID).

    Attributes:
        evaluated_frame_count (int):
            Output only. The number of video frames used
            to create this evaluation.
        evaluated_bounding_box_count (int):
            Output only. The total number of bounding
            boxes (i.e. summed over all frames) the ground
            truth used to create this evaluation had.
        bounding_box_metrics_entries (MutableSequence[google.cloud.automl_v1beta1.types.BoundingBoxMetricsEntry]):
            Output only. The bounding boxes match metrics
            for each Intersection-over-union threshold
            0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each
            label confidence threshold
            0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
        bounding_box_mean_average_precision (float):
            Output only. The single metric for bounding boxes
            evaluation: the mean_average_precision averaged over all
            bounding_box_metrics_entries.
    """

    evaluated_frame_count: int = proto.Field(
        proto.INT32,
        number=1,
    )
    evaluated_bounding_box_count: int = proto.Field(
        proto.INT32,
        number=2,
    )
    bounding_box_metrics_entries: MutableSequence[
        "BoundingBoxMetricsEntry"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message="BoundingBoxMetricsEntry",
    )
    bounding_box_mean_average_precision: float = proto.Field(
        proto.FLOAT,
        number=6,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
